
import { useEffect } from 'react';
import Navigation from '@/components/Navigation';
import Footer from '@/components/Footer';
import ContactHero from '@/components/ContactHero';
import ContactForm from '@/components/ContactForm';
import ContactSidebar from '@/components/ContactSidebar';
import SEOHead from '@/components/SEOHead';

const Contact = () => {
  const schema = {
    "@context": "https://schema.org",
    "@type": "Organization",
    "name": "The IEP Coach - Special Education Advocacy and Support",
    "description": "Professional advocacy services supporting families, students, and educators through expert IEP representation, legal education consulting, and special education resources.",
    "mainEntity": {
      "@type": "DefinedTermSet",
      "name": "Special Education Advocacy Keywords",
      "url": "https://www.theiepcoach.com",
      "hasDefinedTerm": [
        { "@type": "DefinedTerm", "name": "Professional Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Support" },
        { "@type": "DefinedTerm", "name": "Expert IEP Advocacy" },
        { "@type": "DefinedTerm", "name": "Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Education Services" },
        { "@type": "DefinedTerm", "name": "IEP Coach" },
        { "@type": "DefinedTerm", "name": "Special Education Advocacy" },
        { "@type": "DefinedTerm", "name": "Family Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Services" },
        { "@type": "DefinedTerm", "name": "Education Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Advocacy Support" },
        { "@type": "DefinedTerm", "name": "Educational Advocacy" },
        { "@type": "DefinedTerm", "name": "Professional Advocacy Consultant" },
        { "@type": "DefinedTerm", "name": "Legal Education Advocate Services" },
        { "@type": "DefinedTerm", "name": "Disability Education Support" },
        { "@type": "DefinedTerm", "name": "Expert IEP Consultant" },
        { "@type": "DefinedTerm", "name": "Best IEP Advocate Services" },
        { "@type": "DefinedTerm", "name": "TheIEPCoach" },
        { "@type": "DefinedTerm", "name": "Educational Legal Advocacy" }
      ]
    }
  };

  // Scroll to top when component mounts
  useEffect(() => {
    window.scrollTo({ top: 0, behavior: 'smooth' });
  }, []);

  return (
    <div className="min-h-screen">
      <SEOHead
        title="Contact The IEP Coach | Special Education Support & Advocacy"
        description="Contact The IEP Coach for personalized special education advocacy, ARD meeting support, and IEP guidance. Get the help your child deserves."
        keywords="ARD, Special Education, Resource, Functional Academics, Behavior Support, MDR, IHP, Individualized Health Plan, IDEA, Sped, contact IEP advocate, special education support, ARD meeting help, IEP consultation, special education advocacy services"
        canonical="https://www.theiepcoach.com/contact"
        openGraph={{
          title: "Contact The IEP Coach - Special Education Advocacy",
          description: "Contact The IEP Coach for personalized special education advocacy, ARD meeting support, and IEP guidance. Get the help your child deserves.",
          image: "https://www.theiepcoach.com/lovable-uploads/0a09e87f-544f-4502-bfe9-30850c1f8cdb.png",
          url: "https://www.theiepcoach.com/contact"
        }}
        schema={schema}
      />
      <Navigation />
      
      <ContactHero />

      <section className="py-16">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-3 gap-12">
            
            {/* Contact Form */}
            <div className="lg:col-span-2">
              <ContactForm />
            </div>

            {/* Contact Information Sidebar */}
            <ContactSidebar />
          </div>
        </div>
      </section>

      <Footer />
    </div>
  );
};

export default Contact;
